@@ -6,7 +6,7 @@
 #' @import rgl
 #' @import data.table
 #' @import stringr
-#' @importFrom utils globalVariables tail
+#' @importFrom utils globalVariables tail combn
 
 
 
@@ -18,7 +18,7 @@
     c("quadrant","quadrant.new","prior.quadrant",".","tmp.x","tmp.y","min_x_seg","max_x_seg","min_y_seg","max_y_seg",
       "mean_y_seg","mean_x_seg","sub.clpm",'sub.cupm','sub.dlpm','sub.dupm','weight','mean.x','mean.y',
       "Coefficient","X.Lower.Range","X.Upper.Range","y.hat","interval",
-      "NNS.ID","max.x1","max.x2","min.x1","min.x2","counts",
+      "NNS.ID","max.x1","max.x2","min.x1","min.x2","counts",'old.counts',
       "Period","Coefficient.of.Variance","Variable.Coefficient.of.Variance",
       "i.x","i.y","q_new","x.x","x.y","standard.errors"
     ))
